#! /bin/bash
# -*- mode: Bash; tab-width: 2; indent-tabs-mode: nil; coding: utf-8 -*-
# vim:shiftwidth=4:softtabstop=4:tabstop=4:
set -e
set -x

project="pinball"
profile="pincab"
git_url="https://github.com/rzr/pinball"
git_branch="master"
git_branch="sandbox/rzr/devel/master" # TODO
arch="${PINBALL_ARCH}" # TODO : i386
sudo=$(which sudo || echo)
PINBALL_EXPERIMENTAL=true

. /etc/pinball/pinball.env.sh ||:

echo "# Update repository"
mount -o remount,rw /
$sudo sync
$sudo apt-get update
$sudo apt-get install -y etckeeper # ~127MB

echo "# Main package"
$sudo apt-get install -y pinball # ~200MB
# Suggests: alsa-utils
# Install: xterm x11-utils ...

echo "# Hardware support"
case arch in
    i386)
        $sudo apt-get install linux-image-686 grub-pc
        ;;
esac

echo "# Graphics system: ${PINBALL_DISPLAY_MANAGER} (x11 or wayland)"

echo "# Audio"
which aplay || $sudo apt-get install -y alsa-utils #~5MB

if [ "${PINBALL_DISPLAY_MANAGER}" = "weston" ]; then
    echo "# Optional for sdl2 (Add ~20MB)"
    $sudo apt-get install -y \
            kbd \
            weston \
            xwayland \
            # EOL
else
    $sudo apt-get install -y \
            xinit \
            x11-xserver-utils \
            xloadimage \
            # EOL
fi

echo "# Readonly filesystem"
if [ ! -r /etc/fstab ] \
       || grep '# UNCONFIGURED FSTAB FOR BASE SYSTEM' /etc/fstab ; then \
    cat<<EOF | $sudo tee /etc/fstab ||:
# file://etc/fstab # for pinball
none /tmp tmpfs size=16M,mode=1777 0 0
tmpfs /run tmpfs size=32M,nosuid,noexec,relatime,mode=755 0 0
none /var/log tmpfs size=16M,mode=1777 0 0
none /root/.emilia tmpfs size=1M,mode=1777 0 0
EOF
fi

echo "# Maintenance mode"
if ! false; then
    $sudo apt-get install -y \
          aptitude \
          grub-invaders \
          mosh \
          memtest86+ \
          network-manager \
          openssh-server \
          screen \
          sudo \
          time \
          tmux \
          zile \
          # EOL ~7MB
          
    line='PermitRootLogin yes'
    grep "^$line" /etc/ssh/sshd_config || echo "$line" | $sudo tee -a
fi

echo "# Update to experimental packages"
if [ "$PINBALL_EXPERIMENTAL" != "" ]; then
    $sudo apt-get install -y base-files gnupg curl # ~17MB

    . /etc/os-release
    distro="${ID}_${VERSION_ID}"
    if [ "debian" = "${ID}" ] ; then
        [ "${VERSION_ID}" != "" ] || VERSION_ID="10"
        distro="${ID}_${VERSION_ID}"
        [ "${VERSION_ID}" = "10" ] || distro="${distro}.0"
    elif [ "ubuntu" = "$ID" ] ; then
        distro="x${distro}"
    fi
    distro=$(echo "${distro}" | sed 's/.*/\u&/')
    url="http://download.opensuse.org/repositories"
    url="$url/home:/rzrfreefr"
    url="${url}/${distro}"
    list="/etc/apt/sources.list.d/${project}.list"
    echo "deb [allow-insecure=yes] $url /" | $sudo tee "$list"
    suffix="-snapshot"

    curl -s "${url}/Release.key" | gpg --with-fingerprint
    curl "${url}/Release.key" | $sudo apt-key add -v -

    $sudo apt-get update
    $sudo apt-cache show ${project}
    $sudo apt-cache show ${project}${suffix}

    version=$(apt-cache show "${project}${suffix}" \
                  | grep 'Version:' | cut -d' ' -f2 | sort -n | head -n1 \
                  || echo 0)

    $sudo apt-get remove -y pinball ||:

    $sudo apt-get install --yes \
            --allow-downgrades  --allow-unauthenticated \
            ${project}${suffix}=${version} \
            ${project}=${version} \
            ${project}-data=${version} \
        ||:
    
    apt-cache search pinball-table   
    $sudo apt-get install --yes \
            --allow-downgrades --allow-unauthenticated \
            pinball-table-gnu${suffix} \
            pinball-table-hurd${suffix} ||:
fi

echo "# Add Sources for legal info"
rm -rf /usr/local/opt/${project}
mkdir -p /usr/local/opt/${project}/src/
cd /usr/local/opt/${project}/src/
git clone --branch "${git_branch}" --depth 1 "${git_url}"

echo "# Add launcher for profile=${profile}"
cd /usr/local/opt/${project}/src/${project}
cp -rfav extra/profile/pinball/etc/pinball /etc/
[ "$profile" = "" ] || cp -rfav extra/profile/${profile}/etc/pinball /etc/
bash -x -e /etc/pinball/setup.sh

echo "# Theming"
$sudo apt-get install localepurge
$sudo dpkg-reconfigure locales # en_US.UTF-8
cat /etc/environment
apt-cache search plymouth  
cat /etc/issue.net
cat /etc/issue

echo "# Cleanup"
$sudo apt-get install deborphan # 22MB
# remove all locales , en_US.UTF-8
$sudo apt-get clean
$sudo rm -rf /var/lib/apt/lists/*
df -h # /dev/sda1       3.7G 1021M  2.5G  30% /
deborphan # bsdmainutils

echo "# Reboot"
history -c
echo "# https://purl.org/rzr/pinball # for more"
mount -o remount,rw /
echo reboot # TODO
